@@ -42,6 +42,7 @@ class BaseClient(object):
         http_client=requests,
         checksum_generator_factory=None,
         signature_builder_factory=None,
+        **factories,
     ):
         self.priv_key = priv_key
         self.priv_key_passphrase = priv_key_passphrase or None
@@ -90,6 +91,21 @@ class BaseClient(object):
 
         self._signature_builder_factory = signature_builder_factory
 
+        unexpected_factories = set(factories) - {
+            'orden_factory',
+            'respuesta_response_factory',
+        }
+
+        if unexpected_factories:
+            unexpected = ', '.join(sorted(unexpected_factories))
+            raise TypeError(f'Unexpected factory arguments: {unexpected}')
+
+        self._orden_factory = factories.get('orden_factory', Orden)
+        self._respuesta_response_factory = factories.get(
+            'respuesta_response_factory',
+            RespuestaResponse,
+        )
+
     @property
     def signature_builder_factory(self):
         return self._signature_builder_factory
@@ -116,14 +132,25 @@ class BaseClient(object):
         )
         self._signature_builder_factory = factory
 
-    def registra_orden(
-        self,
-        orden_data,
-        orden_cls=Orden,
-        respuesta_response_cls=RespuestaResponse,
-    ):
+    @property
+    def orden_factory(self):
+        return self._orden_factory
+
+    @orden_factory.setter
+    def orden_factory(self, factory):
+        self._orden_factory = factory
+
+    @property
+    def respuesta_response_factory(self):
+        return self._respuesta_response_factory
+
+    @respuesta_response_factory.setter
+    def respuesta_response_factory(self, factory):
+        self._respuesta_response_factory = factory
+
+    def registra_orden(self, orden_data):
         signature = self.generate_signature(orden_data)
-        orden = orden_cls(op_firma_dig=signature, **orden_data)
+        orden = self._orden_factory(op_firma_dig=signature, **orden_data)
         soap_request = OrdenRequest(orden).to_string()
         logger.info(soap_request)
 
@@ -131,7 +158,7 @@ class BaseClient(object):
         logger.info(response.text)
         response.raise_for_status()
 
-        respuesta = respuesta_response_cls(response.text)
+        respuesta = self._respuesta_response_factory(response.text)
 
         if respuesta.err_codigo != errors.GenericoCodigoError.exitoso:
             self._raise_error(respuesta)
