@@ -1,13 +1,18 @@
+from typing import Type
+
 from lxml import etree
 
 from spei.resources import Orden
 
 
 class OrdenPagoElement(object):
-    def __new__(cls, mensaje_element, orden_cls: Orden = Orden):
+    def __init__(self, orden_parser: Type[Orden] = Orden):
+        self._orden_parser = orden_parser
+
+    def __call__(self, mensaje_element):
         ordenpago = mensaje_element.find('ordenpago')
         categoria = mensaje_element.attrib['categoria']
-        return orden_cls.parse_xml(ordenpago, categoria)
+        return self._orden_parser.parse_xml(ordenpago, categoria)
 
 
 class MensajeElement(object):
@@ -30,8 +35,9 @@ class BodyElement(object):
 
 
 class OrdenResponse(object):
-    def __new__(cls, orden):
+    def __new__(cls, orden, orden_parser: Type[Orden] = Orden):
         mensaje = etree.fromstring(  # noqa: S320
             bytes(orden, encoding='cp850'),
         )
-        return OrdenPagoElement(MensajeElement(RootElement(BodyElement(mensaje))))
+        element = OrdenPagoElement(orden_parser)
+        return element(MensajeElement(RootElement(BodyElement(mensaje))))
